#!/bin/env python2
from setuptools import setup

setup(
    name="picu",
    version='0.8',
    author="Wil Tan",
    author_email="wil@cloudregistry.net",
    description="Python ctypes-based ICU Wrapper",
    license="MIT/X",
    install_requires=[],
    packages=['picu']
)
